from .client import post_request as post_request
from dataclasses import dataclass
from typing import Any, Self

@dataclass
class MoneybirdModel:
    id: int | None = ...
    @property
    def endpoint(self) -> str: ...
    def to_dict(self, exclude_none: bool = False) -> dict[str, Any]: ...
    def load(self, id: int) -> None: ...
    def save(self) -> None: ...
    def update(self, data: dict[str, Any]) -> None: ...
    def delete(self) -> None: ...
    @classmethod
    def find_by_id(cls, id: int) -> Self: ...
    @classmethod
    def update_by_id(cls, id: int, data: dict[str, Any]) -> Self: ...
    @classmethod
    def delete_by_id(cls, id: int) -> Self: ...
    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> Self: ...
    def __init__(self, id=...) -> None: ...



from .client import MB_URL as MB_URL, MB_VERSION_ID as MB_VERSION_ID, post_request as post_request, set_admin_id as set_admin_id, set_timeout as set_timeout, set_token as set_token
from .contact import Contact as Contact, ContactPerson as ContactPerson
from .external_sales_invoice import ExternalSalesInvoice as ExternalSalesInvoice
from .financial_mutation import FinancialMutation as FinancialMutation
from .financial_statement import FinancialStatement as FinancialStatement
from .payment import Payment as Payment

__all__ = ['MB_URL', 'MB_VERSION_ID', 'post_request', 'set_admin_id', 'set_timeout', 'set_token', 'Contact', 'ContactPerson', 'ExternalSalesInvoice', 'Payment', 'FinancialMutation', 'FinancialStatement']



from dataclasses import dataclass
from typing import Optional

from .client import post_request
from .custom_field_model import CustomFieldModel


@dataclass
class ContactPerson:
    firstname: Optional[str] = None
    lastname: Optional[str] = None


@dataclass
class Contact(CustomFieldModel):
    company_name: Optional[str] = None
    address1: Optional[str] = None
    address2: Optional[str] = None
    zipcode: Optional[str] = None
    city: Optional[str] = None
    country: Optional[str] = None
    phone: Optional[str] = None
    delivery_method: Optional[str] = None
    customer_id: Optional[str] = None
    tax_number: Optional[str] = None
    firstname: Optional[str] = None
    lastname: Optional[str] = None
    chamber_of_commerce: Optional[str] = None
    bank_account: Optional[str] = None
    send_invoices_to_attention: Optional[str] = None
    send_invoices_to_email: Optional[str] = None
    send_estimates_to_attention: Optional[str] = None
    send_estimates_to_email: Optional[str] = None
    sepa_active: bool = False
    sepa_iban: Optional[str] = None
    sepa_iban_account_name: Optional[str] = None
    sepa_bic: Optional[str] = None
    sepa_mandate_id: Optional[str] = None
    sepa_mandate_date: Optional[str] = None
    sepa_sequence_type: Optional[str] = None
    si_identifier_type: Optional[str] = None
    si_identifier: Optional[str] = None
    invoice_workflow_id: Optional[int] = None
    estimate_workflow_id: Optional[int] = None
    email_ubl: bool = False
    direct_debit: bool = False
    contact_person: Optional[ContactPerson] = None
    type: Optional[str] = None
    from_checkout: bool = False

    @staticmethod
    def find_by_customer_id(customer_id: str) -> "Contact":
        """
        Find a contact by customer_id
        """
        data = post_request(f"contacts/customer_id/{customer_id}", method="get")
        return Contact.from_dict(data)



from .client import post_request as post_request
from .custom_field_model import CustomFieldModel as CustomFieldModel
from dataclasses import dataclass

@dataclass
class ContactPerson:
    firstname: str | None = ...
    lastname: str | None = ...
    def __init__(self, firstname=..., lastname=...) -> None: ...

@dataclass
class Contact(CustomFieldModel):
    company_name: str | None = ...
    address1: str | None = ...
    address2: str | None = ...
    zipcode: str | None = ...
    city: str | None = ...
    country: str | None = ...
    phone: str | None = ...
    delivery_method: str | None = ...
    customer_id: str | None = ...
    tax_number: str | None = ...
    firstname: str | None = ...
    lastname: str | None = ...
    chamber_of_commerce: str | None = ...
    bank_account: str | None = ...
    send_invoices_to_attention: str | None = ...
    send_invoices_to_email: str | None = ...
    send_estimates_to_attention: str | None = ...
    send_estimates_to_email: str | None = ...
    sepa_active: bool = ...
    sepa_iban: str | None = ...
    sepa_iban_account_name: str | None = ...
    sepa_bic: str | None = ...
    sepa_mandate_id: str | None = ...
    sepa_mandate_date: str | None = ...
    sepa_sequence_type: str | None = ...
    si_identifier_type: str | None = ...
    si_identifier: str | None = ...
    invoice_workflow_id: int | None = ...
    estimate_workflow_id: int | None = ...
    email_ubl: bool = ...
    direct_debit: bool = ...
    contact_person: ContactPerson | None = ...
    type: str | None = ...
    from_checkout: bool = ...
    @staticmethod
    def find_by_customer_id(customer_id: str) -> Contact: ...
    def __init__(self, id=..., company_name=..., address1=..., address2=..., zipcode=..., city=..., country=..., phone=..., delivery_method=..., customer_id=..., tax_number=..., firstname=..., lastname=..., chamber_of_commerce=..., bank_account=..., send_invoices_to_attention=..., send_invoices_to_email=..., send_estimates_to_attention=..., send_estimates_to_email=..., sepa_active=..., sepa_iban=..., sepa_iban_account_name=..., sepa_bic=..., sepa_mandate_id=..., sepa_mandate_date=..., sepa_sequence_type=..., si_identifier_type=..., si_identifier=..., invoice_workflow_id=..., estimate_workflow_id=..., email_ubl=..., direct_debit=..., contact_person=..., type=..., from_checkout=...) -> None: ...



from dataclasses import dataclass
from typing import Optional

from .model import MoneybirdModel


@dataclass
class CustomField:
    id: Optional[int] = None
    value: Optional[str] = None


class CustomFieldModel(MoneybirdModel):
    custom_fields: list[CustomField] = []

    def get_custom_field(self, field_id: int) -> str | None:
        for field in self.custom_fields:
            if field.id == field_id:
                return field.value
        return None

    def set_custom_field(self, field_id: int, value: str) -> None:
        for field in self.custom_fields:
            if field.id == field_id:
                field.value = value
                return
        self.custom_fields.append(CustomField(id=field_id, value=value))



from .financial_mutation import FinancialMutation as FinancialMutation
from .model import MoneybirdModel as MoneybirdModel
from dataclasses import dataclass
from typing import Self

@dataclass
class FinancialStatement(MoneybirdModel):
    financial_account_id: str | None = ...
    reference: str | None = ...
    official_date: str | None = ...
    official_balance: str | None = ...
    importer_service: str | None = ...
    financial_mutations: list[FinancialMutation] = ...
    def load(self, id: int) -> None: ...
    @classmethod
    def find_by_id(cls, id: int) -> Self: ...
    def __init__(self, id=..., financial_account_id=..., reference=..., official_date=..., official_balance=..., importer_service=..., financial_mutations=...) -> None: ...



from dataclasses import dataclass
from typing import Any, Optional, Self, Union, get_origin, get_args
import inspect

from .client import post_request


@dataclass
class MoneybirdModel:
    id: Optional[int] = None

    @property
    def endpoint(self) -> str:
        return "".join(
            [
                "_" + letter.lower() if letter.isupper() else letter
                for letter in self.__class__.__name__
            ]
        ).lstrip("_")

    def to_dict(self, exclude_none: bool = False) -> dict[str, Any]:
        def convert_value(value: Any) -> Any:
            if isinstance(value, MoneybirdModel):
                return value.to_dict()
            return value

        return {
            key: convert_value(value)
            for key, value in self.__dict__.items()
            if not (exclude_none and value is None)
        }

    def load(self, id: int) -> None:
        data = post_request(f"{self.endpoint}s/{id}", method="get")
        self.update(data)

    def save(self) -> None:
        if self.id is None:
            data = post_request(
                f"{self.endpoint}s",
                data={self.endpoint: self.to_dict()},
                method="post",
            )
            # update the current object with the data
            self.update(data)
        else:
            data = post_request(
                f"{self.endpoint}s/{self.id}",
                data={self.endpoint: self.to_dict()},
                method="patch",
            )
            self.update(data)

    def update(self, data: dict[str, Any]) -> None:
        for key, value in data.items():
            if hasattr(self, key):
                setattr(self, key, value)

    def delete(self) -> None:
        if not self.id:
            raise ValueError(f"Cannot delete {self.__class__.__name__} without an id")
        post_request(f"{self.endpoint}s/{self.id}", method="delete")
        # remove the id from the object
        self.id = None

    @classmethod
    def find_by_id(cls: type[Self], id: int) -> Self:
        entity = cls()
        entity.load(id)
        return entity

    @classmethod
    def update_by_id(cls: type[Self], id: int, data: dict[str, Any]) -> Self:
        entity = cls(id)
        entity.update(data)
        entity.save()
        return entity

    @classmethod
    def delete_by_id(cls: type[Self], id: int) -> Self:
        entity = cls(id)
        entity.delete()
        return entity

    @classmethod
    def _get_param_type(cls, param_type: Any) -> Any:
        """
        Resolve the actual type of a parameter, handling Optionals and Unions.
        """
        if param_type is not inspect.Parameter.empty:
            origin = get_origin(param_type)
            args = get_args(param_type)
            if origin is Union and type(None) in args:
                return next(arg for arg in args if arg is not type(None))
        return param_type

    @classmethod
    def _convert_value(cls, value: Any, param_type: Any) -> Any:
        """
        Attempt to convert a value to the given parameter type.
        """
        if value is not None:
            try:
                return param_type(value)
            except (ValueError, TypeError):
                pass
        return value

    @classmethod
    def _filter_params(
        cls, data: dict[str, Any], params: inspect.Signature
    ) -> dict[str, Any]:
        """
        Filter and convert input data based on class parameters.
        """
        filtered_data = {}
        for key, value in data.items():
            if key in params:
                param_type = cls._get_param_type(params[key].annotation)
                filtered_data[key] = cls._convert_value(value, param_type)
        return filtered_data

    @classmethod
    def from_dict(cls: type[Self], data: dict[str, Any]) -> Self:
        """
        Create an instance of the class from a dictionary, performing type conversion.
        """
        params = inspect.signature(cls).parameters
        filtered_data = cls._filter_params(data, params)
        return cls(**{k: v for k, v in filtered_data.items() if k in params})



from .client import post_request as post_request
from .model import MoneybirdModel as MoneybirdModel
from dataclasses import dataclass
from enum import Enum
from typing import Any, Self

class LinkBookingType(Enum):
    LedgerAccount = ...
    SalesInvoice = ...
    Document = ...
    PaymentTransactionBatch = ...
    PurchaseTransaction = ...
    NewPurchaseInvoice = ...
    NewReceipt = ...
    PaymentTransaction = ...
    PurchaseTransactionBatch = ...
    ExternalSalesInvoice = ...
    Payment = ...
    VatDocument = ...

class UnlinkBookingType(Enum):
    LedgerAccountBooking = ...
    Payment = ...

@dataclass
class FinancialMutation(MoneybirdModel):
    id: str | None = ...
    administration_id: str | None = ...
    amount: str | None = ...
    code: str | None = ...
    date: str | None = ...
    message: str | None = ...
    contra_account_name: str | None = ...
    contra_account_number: str | None = ...
    state: str | None = ...
    amount_open: str | None = ...
    sepa_fields: str | None = ...
    batch_reference: str | None = ...
    financial_account_id: str | None = ...
    currency: str | None = ...
    original_amount: str | None = ...
    created_at: str | None = ...
    updated_at: str | None = ...
    version: str | None = ...
    financial_statement_id: str | None = ...
    processed_at: str | None = ...
    account_servicer_transaction_id: str | None = ...
    payments: list = ...
    ledger_account_bookings: list = ...
    def save(self) -> None: ...
    def delete(self) -> None: ...
    def book_payment(self, price_base: float, booking_id: int, booking_type: LinkBookingType = ...) -> None: ...
    def remove_payment(self, booking_id: int, booking_type: UnlinkBookingType = ...) -> None: ...
    @classmethod
    def update_by_id(cls, id: int, data: dict[str, Any]) -> Self: ...
    @classmethod
    def delete_by_id(cls, id: int) -> Self: ...
    def __init__(self, id=..., administration_id=..., amount=..., code=..., date=..., message=..., contra_account_name=..., contra_account_number=..., state=..., amount_open=..., sepa_fields=..., batch_reference=..., financial_account_id=..., currency=..., original_amount=..., created_at=..., updated_at=..., version=..., financial_statement_id=..., processed_at=..., account_servicer_transaction_id=..., payments=..., ledger_account_bookings=...) -> None: ...



from typing import Any, List, Optional, Self
from dataclasses import dataclass, field
from enum import Enum, auto

from .model import MoneybirdModel
from .client import post_request


class LinkBookingType(Enum):
    """
    Enum for the different types of bookings that can be linked to a financial mutation.
    """

    LedgerAccount = auto()
    SalesInvoice = auto()
    Document = auto()
    PaymentTransactionBatch = auto()
    PurchaseTransaction = auto()
    NewPurchaseInvoice = auto()
    NewReceipt = auto()
    PaymentTransaction = auto()
    PurchaseTransactionBatch = auto()
    ExternalSalesInvoice = auto()
    Payment = auto()
    VatDocument = auto()


class UnlinkBookingType(Enum):
    """
    Enum for the different types of bookings that can be unlinked from a financial mutation.
    """

    LedgerAccountBooking = auto()
    Payment = auto()


@dataclass
class FinancialMutation(MoneybirdModel):
    """
    Represents a financial mutation in Moneybird.
    """

    id: Optional[str] = None
    administration_id: Optional[str] = None
    amount: Optional[str] = None
    code: Optional[str] = None
    date: Optional[str] = None
    message: Optional[str] = None
    contra_account_name: Optional[str] = None
    contra_account_number: Optional[str] = None
    state: Optional[str] = None
    amount_open: Optional[str] = None
    sepa_fields: Optional[str] = None
    batch_reference: Optional[str] = None
    financial_account_id: Optional[str] = None
    currency: Optional[str] = None
    original_amount: Optional[str] = None
    created_at: Optional[str] = None
    updated_at: Optional[str] = None
    version: Optional[str] = None
    financial_statement_id: Optional[str] = None
    processed_at: Optional[str] = None
    account_servicer_transaction_id: Optional[str] = None
    payments: List = field(default_factory=list)
    ledger_account_bookings: List = field(default_factory=list)

    # Disable create, update and delete methods for financial mutations as they don't
    # exist in the Moneybird API.
    def save(self) -> None:
        raise NotImplementedError("Financial mutations cannot be saved in Moneybird.")

    def delete(self) -> None:
        raise NotImplementedError("Financial mutations cannot be deleted in Moneybird.")

    def book_payment(
        self,
        price_base: float,
        booking_id: int,
        booking_type: LinkBookingType = LinkBookingType.LedgerAccount,
    ) -> None:
        """
        Book a payment on this financial mutation.
        """
        post_request(
            f"financial_mutations/{self.id}/link_booking",
            {
                "price_base": price_base,
                "booking_id": booking_id,
                "booking_type": booking_type,
            },
            method="PATCH",
        )

    def remove_payment(
        self,
        booking_id: int,
        booking_type: UnlinkBookingType = UnlinkBookingType.LedgerAccountBooking,
    ) -> None:
        """
        Remove a payment from this financial mutation.
        """
        post_request(
            f"financial_mutations/{self.id}/unlink_booking",
            {"booking_id": booking_id, "booking_type": booking_type},
            method="PATCH",
        )

    @classmethod
    def update_by_id(cls: type[Self], id: int, data: dict[str, Any]) -> Self:
        raise NotImplementedError("Financial mutations cannot be updated in Moneybird.")

    @classmethod
    def delete_by_id(cls: type[Self], id: int) -> Self:
        raise NotImplementedError("Financial mutations cannot be deleted in Moneybird.")



from typing import List, Optional, Self
from dataclasses import dataclass, field

from .model import MoneybirdModel
from .financial_mutation import FinancialMutation


@dataclass
class FinancialStatement(MoneybirdModel):
    """
    Represents a financial statement in Moneybird.
    """

    financial_account_id: Optional[str] = None
    reference: Optional[str] = None
    official_date: Optional[str] = None
    official_balance: Optional[str] = None
    importer_service: Optional[str] = None
    financial_mutations: List[FinancialMutation] = field(default_factory=list)

    def load(self, id: int) -> None:
        raise NotImplementedError(
            "Financial statements cannot be loaded from Moneybird."
        )

    @classmethod
    def find_by_id(cls: type[Self], id: int) -> Self:
        raise NotImplementedError(
            "Financial statements cannot be loaded from Moneybird."
        )



from .model import MoneybirdModel as MoneybirdModel
from dataclasses import dataclass

@dataclass
class CustomField:
    id: int | None = ...
    value: str | None = ...
    def __init__(self, id=..., value=...) -> None: ...

class CustomFieldModel(MoneybirdModel):
    custom_fields: list[CustomField]
    def get_custom_field(self, field_id: int) -> str | None: ...
    def set_custom_field(self, field_id: int, value: str) -> None: ...



from dataclasses import dataclass, field
import inspect
from typing import Any, Optional, List, Self

from .model import MoneybirdModel
from .client import post_request
from .payment import Payment


@dataclass
class ExternalSalesInvoiceDetailsAttributes:
    """
    Details attributes for an external sales invoice.
    """

    id: Optional[int] = None
    description: Optional[str] = None
    period: Optional[str] = None
    price: Optional[int] = None
    amount: Optional[int] = None
    tax_rate_id: Optional[int] = None
    ledger_account_id: Optional[str] = None
    project_id: Optional[str] = None

    @classmethod
    def from_dict(cls: type[Self], data: dict[str, Any]) -> Self:
        return cls(
            **{k: v for k, v in data.items() if k in inspect.signature(cls).parameters}
        )


# External sales invoices don't have custom fields, so we use MoneybirdModel
# instead of CustomFieldModel.
@dataclass
class ExternalSalesInvoice(MoneybirdModel):
    """
    Represents an external sales invoice in Moneybird.
    """

    contact_id: Optional[int] = None
    reference: Optional[str] = None
    date: Optional[str] = None
    due_date: Optional[str] = None
    currency: Optional[str] = None
    prices_are_incl_tax: Optional[bool] = None
    source: Optional[str] = None
    source_url: Optional[str] = None
    details: Optional[List[ExternalSalesInvoiceDetailsAttributes]] = field(
        default_factory=list
    )
    payments: Optional[List[Payment]] = field(default_factory=list)

    def update(self, data: dict[str, Any]) -> None:
        """
        Update the external sales invoice. Overrides the update method in MoneybirdModel.
        """
        super().update(data)
        self.details = [
            (
                ExternalSalesInvoiceDetailsAttributes.from_dict(d)
                if isinstance(d, dict)
                else d
            )
            for d in self.details
        ]
        self.payments = [
            Payment.from_dict(p) if isinstance(p, dict) else p for p in self.payments
        ]

    def save(self) -> None:
        """
        Save the external sales invoice. Overrides the save method in MoneybirdModel.
        """
        invoice_data = self.to_dict()
        # For the POST and PATCH requests we need to use the details_attributes key
        # instead of details key to match the Moneybird API.
        invoice_data["details_attributes"] = invoice_data.pop("details", [])

        if self.id is None:
            data = post_request(
                f"{self.endpoint}s",
                data={self.endpoint: invoice_data},
                method="post",
            )
            self.update(data)
        else:
            data = post_request(
                f"{self.endpoint}s/{self.id}",
                data={self.endpoint: invoice_data},
                method="patch",
            )
            self.update(data)

    def list_all_by_contact_id(
        self,
        contact_id: int,
        state: Optional[str] = "all",
        period: Optional[str] = "this_year",
    ) -> List:
        """
        List all external sales invoices for a contact.
        """
        data = post_request(
            path=f"{self.endpoint}s/?filter=contact_id:{contact_id}&state:{state}&period:{period}",
            method="get",
        )

        invoices = []
        for invoice in data:
            invoice_obj = ExternalSalesInvoice.from_dict(invoice)
            if "details" in invoice:
                invoice_obj.details = [
                    ExternalSalesInvoiceDetailsAttributes.from_dict(detail)
                    for detail in invoice["details"]
                ]
            if "payments" in invoice:
                invoice_obj.payments = [
                    Payment.from_dict(payment) for payment in invoice["payments"]
                ]
            invoices.append(invoice_obj)
        return invoices

    def create_payment(self, payment: Payment) -> None:
        """
        Create a payment for the external sales invoice.
        """
        data = post_request(
            path=f"{self.endpoint}s/{self.id}/payments",
            data={"payment": payment.to_dict()},
        )
        # Get the payment data from the response and append it to the payments list
        payment_data = data.get("payment")
        if payment_data:
            self.payments.append(Payment.from_dict(payment_data))

    def delete_payment(self, payment_id: int) -> None:
        """
        Delete a payment for the external sales invoice.
        """
        post_request(
            path=f"{self.endpoint}s/{self.id}/payments/{payment_id}",
            method="delete",
        )

        self.payments = [
            payment for payment in self.payments if payment.id != payment_id
        ]



from dataclasses import dataclass
from typing import Optional

from .model import MoneybirdModel


@dataclass
class Payment(MoneybirdModel):
    """
    Represents a payment in Moneybird.
    """

    payment_date: Optional[str] = None
    price: Optional[float] = None
    price_base: Optional[float] = None
    financial_account_id: Optional[int] = None
    financial_mutation_id: Optional[int] = None
    manual_payment_action: Optional[str] = "bank_transfer"
    transaction_identifier: Optional[str] = None
    ledger_account_id: Optional[int] = None
    invoice_id: Optional[int] = None

    def save(self) -> None:
        raise NotImplementedError(
            "Payments cannot be saved directly. Refer to the invoice that the payment is for."
        )

    def delete(self) -> None:
        raise NotImplementedError(
            "Payments cannot be deleted directly. Refer to the invoice that the payment is for."
        )



from .client import post_request as post_request
from .model import MoneybirdModel as MoneybirdModel
from .payment import Payment as Payment
from dataclasses import dataclass
from typing import Any, Self

@dataclass
class ExternalSalesInvoiceDetailsAttributes:
    id: int | None = ...
    description: str | None = ...
    period: str | None = ...
    price: int | None = ...
    amount: int | None = ...
    tax_rate_id: int | None = ...
    ledger_account_id: str | None = ...
    project_id: str | None = ...
    @classmethod
    def from_dict(cls, data: dict[str, Any]) -> Self: ...
    def __init__(self, id=..., description=..., period=..., price=..., amount=..., tax_rate_id=..., ledger_account_id=..., project_id=...) -> None: ...

@dataclass
class ExternalSalesInvoice(MoneybirdModel):
    contact_id: int | None = ...
    reference: str | None = ...
    date: str | None = ...
    due_date: str | None = ...
    currency: str | None = ...
    prices_are_incl_tax: bool | None = ...
    source: str | None = ...
    source_url: str | None = ...
    details: list[ExternalSalesInvoiceDetailsAttributes] | None = ...
    payments: list[Payment] | None = ...
    def update(self, data: dict[str, Any]) -> None: ...
    def save(self) -> None: ...
    def list_all_by_contact_id(self, contact_id: int, state: str | None = 'all', period: str | None = 'this_year') -> list: ...
    def create_payment(self, payment: Payment) -> None: ...
    def delete_payment(self, payment_id: int) -> None: ...
    def __init__(self, id=..., contact_id=..., reference=..., date=..., due_date=..., currency=..., prices_are_incl_tax=..., source=..., source_url=..., details=..., payments=...) -> None: ...



from .model import MoneybirdModel as MoneybirdModel
from dataclasses import dataclass

@dataclass
class Payment(MoneybirdModel):
    payment_date: str | None = ...
    price: float | None = ...
    price_base: float | None = ...
    financial_account_id: int | None = ...
    financial_mutation_id: int | None = ...
    manual_payment_action: str | None = ...
    transaction_identifier: str | None = ...
    ledger_account_id: int | None = ...
    invoice_id: int | None = ...
    def save(self) -> None: ...
    def delete(self) -> None: ...
    def __init__(self, id=..., payment_date=..., price=..., price_base=..., financial_account_id=..., financial_mutation_id=..., manual_payment_action=..., transaction_identifier=..., ledger_account_id=..., invoice_id=...) -> None: ...



from typing import Any

import httpx

MB_URL = "https://moneybird.com/api"
MB_VERSION_ID = "v2"

# Moneybird settings
admin_id_ = 0
token_ = ""
timeout_ = 20


def set_admin_id(admin_id: int) -> None:
    global admin_id_
    admin_id_ = admin_id


def set_token(token: str) -> None:
    global token_
    token_ = token


def set_timeout(timeout: int) -> None:
    global timeout_
    timeout_ = timeout


def post_request(
    path: str, data: dict[str, Any] | None = None, method: str = "post"
) -> dict[str, Any]:
    headers = {
        "Authorization": f"Bearer {token_}",
        "Content-Type": "application/json",
    }
    fullpath = f"{MB_URL}/{MB_VERSION_ID}/{admin_id_}/{path}"
    response = httpx.request(
        method, fullpath, json=data, headers=headers, timeout=timeout_
    )
    response.raise_for_status()

    # return json if there is content
    return response.json() if response.content else {}
